@@ -1,5 +1,6 @@
 import enum
 import pathlib
+import shutil
 import subprocess
 
 import typer
@@ -18,8 +19,8 @@ class AuthOptions(enum.Enum):
 
 @app.command()
 def version():
-    """Just a placeholder overwritten in CI"""
-    print('0.4.0')
+    """Application version"""
+    print('0.4.4')  # just a placeholder replaced in CI
 
 
 @app.command()
@@ -38,16 +39,21 @@ def create(
     Initialize a FastAPI app at specified path
     """
     print(':flexed_biceps: Creating Project')
-    subprocess.run(['cp', '-r', pathlib.PurePath(pathlib.Path(__file__).resolve().parent, 'fastapi-app'), path])
 
-    if auth in [AuthOptions.self, AuthOptions.backend]:
-        print(f':locked_with_key: Setting up Auth to "{auth.name}"')
-        apply_template_option('auth', auth.name, path)
+    try:
+        shutil.copytree(pathlib.PurePath(pathlib.Path(__file__).resolve().parent, 'fastapi-app/.'), path)
+    except FileExistsError:
+        print(':disappointed: [bold red]Error![/bold red] Directory already exists. '
+              'Please remove it or pick a different directory name')
+    else:
+        if auth in [AuthOptions.self, AuthOptions.backend]:
+            print(f':locked_with_key: Setting up Auth to "{auth.name}"')
+            apply_template_option('auth', auth.name, path)
 
-    if git_init:
-        print(':wrench: Initializing git repo')
-        subprocess.run(['git', 'init', path])
-    print(f':oncoming_fist: The project is setup at: {path}')
+        if git_init:
+            print(':wrench: Initializing git repo')
+            subprocess.run(['git', 'init', '--quiet', path])
+        print(f':oncoming_fist: [bold green]Success![/bold green] The project is setup at: {path}')
 
 
 @app.command()
@@ -55,6 +61,9 @@ def add_model(
         model_name: str = typer.Argument(..., help='Model name - Case sensitive'),
         model_filepath: str = typer.Argument(..., help='Path to the model file. Relative or absolute'),
 ):
+    """
+    Create schemas and crud for a SQLAlchemy model
+    """
     path = pathlib.PurePath(model_filepath).parts
 
     # get app dir for creating schemas and crud
@@ -107,6 +116,7 @@ def add_model(
 
     # Create schemas file
     schemas = [
+        'from pydantic import BaseModel\n\n'
         f'class {model_name}Base(BaseModel):',
         '\n'.join(f'    {col}: {dt}' if type != '' else f'    {col}' for col, dt in cols),
         '\n\n'
