@@ -3,7 +3,7 @@ from typing import Generator
 import httpx
 from app.core.config import settings
 from app.database.session import SessionLocal
-from fastapi import Depends
+from fastapi import Depends, HTTPException, status
 from fastapi.security import OAuth2PasswordBearer
 
 oauth2_scheme = OAuth2PasswordBearer(tokenUrl=f'{settings.API_VERSION}/auth/token')
@@ -18,6 +18,18 @@ def get_db() -> Generator:
         db.close()
 
 
+async def backend_login(username, password):
+    async with httpx.AsyncClient() as client:
+        r = await client.post(f'{settings.BACKEND_URL}/login/access-token',
+                              data={'username': username,
+                                    'password': password
+                                    })
+        if r.status_code != 200:
+            raise HTTPException(status_code=status.HTTP_403_FORBIDDEN,
+                                detail='Invalid username/password combination')
+        return r.json()
+
+
 async def get_user_by_token_from_backend(token: str):
     async with httpx.AsyncClient() as client:
         r = await client.get(f'{settings.BACKEND_URL}/{settings.GET_USER_BY_TOKEN_ENDPOINT}/{token}')
